Welcome to the attractors example.

To run the application::

  python run_attractor.py

Note that this example application depends on the following additional
packages::

  numpy, scipy, chaco, mayavi
